# Pygamelib
- It is python game library.
- It is not pygame.
## Console
### Print2D
- Print 2D List.
- bool(x) is True: print t else: print f
## GUI
### Messagebox
- str message box! (normal, password)
- it's korean.
### Sprite
- sprite
- it can move.
- it can set x.
- it can set y.
- it can get x, y. (tuple)
## Sound
### Sound
- sound
- it's pygame sound.
- but it have loopplay function (name : loopplay)